local AceOO = AceLibrary("AceOO-2.0")

local Addon = AceOO.Class(ShakedownAddonBase, "Metrognome-2.0")

Addon.prototype.barNumber = 5
Addon.prototype.barDuration = { 10, 15, 20, 24, 27 }
Addon.prototype.barFrequency = 30
Addon.prototype.msgFrequency = 3
Addon.prototype.barID = "Shakedown BigWigs %d"
Addon.prototype.testPlugin = nil

-- constructor
function Addon.prototype:init()
    Addon.super.prototype.init(self, "BigWigs", "BigWigs")
end

function Addon.prototype:Activate()

    if not Addon.super.prototype.Activate(self) then return end

    -- activate the addon if necessary
    if not BigWigs:IsActive() then
        BigWigs:ToggleActive(true)
    end
    
    -- activate the test plugin
    if not self.testPlugin then
        self.testPlugin = BigWigs:GetModule("Test")
    end
    if not self.testPlugin then return end
    
    -- show a message now
    self:ShowMessage()
    
    -- show bars now
    self:ShowBar()

    --schedule repeating messages and bars
    self:UnregisterMetro("BigWigsShakedownMessage")
    self:RegisterMetro("BigWigsShakedownMessage", self.ShowMessage, self.msgFrequency, self)
    self:StartMetro("BigWigsShakedownMessage")
    
    self:UnregisterMetro("BigWigsShakedownBars")
    self:RegisterMetro("BigWigsShakedownBars", self.ShowBar, self.barFrequency, self)
    self:StartMetro("BigWigsShakedownBars")
    
end

function Addon.prototype:Deactivate()

    Addon.super.prototype.Deactivate(self)

    -- check existence
    if not BigWigs then return end
    if not self.testPlugin then return end
    
    -- kill the scheduled messages and bars
    self:UnregisterMetro("BigWigsShakedownMessage")
    self:UnregisterMetro("BigWigsShakedownBars")
    
    -- kill each of the bars
    for i = 1, self.barNumber do
        self.testPlugin:TriggerEvent("BigWigs_StopBar", self.testPlugin, string.format(self.barID, i))
    end

end

-- create some bars
function Addon.prototype:ShowBar()

    if not self.testPlugin then return end

    for i = 1, self.barNumber do
        self.testPlugin:Bar( string.format(self.barID, i), self.barDuration[i], "Spell_Nature_ResistNature")
    end

end

-- show a message
function Addon.prototype:ShowMessage()

    if not self.testPlugin then return end
   
    -- display a single message
    self.testPlugin:TriggerEvent("BigWigs_Message", "BigWigs Message", "Important", true)
    
end

-- create the instance of this class
local thisAddon = Addon:new()